==> xscreensaver_4.16.orig.tar.gz: xscreensaver-4.16/hacks/glx/toaster_handle.c <==
#include "gllist.h"
static float data[]={
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,-0.356403,0.038624,0.035224,
	0,0,1,-0.5,-0.094169,0.035224,
	0,0,1,-0.356403,0.038624,0.035224,
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,-0.210084,0.094169,0.035224,
	0,0,1,-0.210084,0.094169,0.035224,
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,0.210084,0.094169,0.035224,
	0,0,1,0.210084,0.094169,0.035224,
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,0.356403,0.038624,0.035224,
	-0.678947,0.734187,0,-0.5,-0.094169,0.035224,
	-0.354908,0.934901,0,-0.356403,0.038624,-0.035224,
	-0.678947,0.734187,0,-0.5,-0.094169,-0.035224,
	-0.354908,0.934901,0,-0.356403,0.038624,-0.035224,
	-0.678947,0.734187,0,-0.5,-0.094169,0.035224,
	-0.180414,0.983591,0,-0.356403,0.038624,0.035224,
	0,0,-1,-0.356403,0.038624,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,-1,-0.5,-0.094169,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,-1,-0.356403,0.038624,-0.035224,
	0,0,0,-0.210084,0.094169,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,0,-0.210084,0.094169,-0.035224,
	0,0,0,0.210084,0.094169,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,0,0.210084,0.094169,-0.035224,
	0,0,0,0.356403,0.038624,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,0.035224,
	0.678947,0.734187,0,0.5,-0.094169,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,-0.035224,
	0.678947,0.734187,0,0.5,-0.094169,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,0.035224,
	0.678947,0.734187,0,0.5,-0.094169,0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,0.035224,
	0.180414,0.983591,0,0.210084,0.094169,-0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,-0.035224,
	0.180414,0.983591,0,0.210084,0.094169,-0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.356403,0.038624,-0.035224,
	0.180414,0.983591,0,0.210084,0.094169,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,-0.035224,
	0.526579,0.850126,0,0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.356403,0.038624,0.035224,
	-0.180414,0.983591,0,-0.356403,0.038624,0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,-0.035224,
	-0.354908,0.934901,0,-0.356403,0.038624,-0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,-0.035224,
	-0.180414,0.983591,0,-0.356403,0.038624,0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,0.035224
};
static struct gllist frame={GL_N3F_V3F,GL_TRIANGLES,54,data,NULL};
struct gllist *toaster_handle=&frame;

==> xscreensaver-5.15.tar.gz: xscreensaver-5.15/hacks/glx/toaster_handle.c <==
#include "gllist.h"
static const float data[]={
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,-0.356403,0.038624,0.035224,
	0,0,1,-0.5,-0.094169,0.035224,
	0,0,1,-0.356403,0.038624,0.035224,
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,-0.210084,0.094169,0.035224,
	0,0,1,-0.210084,0.094169,0.035224,
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,0.210084,0.094169,0.035224,
	0,0,1,0.210084,0.094169,0.035224,
	0,0,1,0.5,-0.094169,0.035224,
	0,0,1,0.356403,0.038624,0.035224,
	-0.678947,0.734187,0,-0.5,-0.094169,0.035224,
	-0.354908,0.934901,0,-0.356403,0.038624,-0.035224,
	-0.678947,0.734187,0,-0.5,-0.094169,-0.035224,
	-0.354908,0.934901,0,-0.356403,0.038624,-0.035224,
	-0.678947,0.734187,0,-0.5,-0.094169,0.035224,
	-0.180414,0.983591,0,-0.356403,0.038624,0.035224,
	0,0,-1,-0.356403,0.038624,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,-1,-0.5,-0.094169,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,-1,-0.356403,0.038624,-0.035224,
	0,0,0,-0.210084,0.094169,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,0,-0.210084,0.094169,-0.035224,
	0,0,0,0.210084,0.094169,-0.035224,
	0,0,0,0.5,-0.094169,-0.035224,
	0,0,0,0.210084,0.094169,-0.035224,
	0,0,0,0.356403,0.038624,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,0.035224,
	0.678947,0.734187,0,0.5,-0.094169,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,-0.035224,
	0.678947,0.734187,0,0.5,-0.094169,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,0.035224,
	0.678947,0.734187,0,0.5,-0.094169,0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,0.035224,
	0.180414,0.983591,0,0.210084,0.094169,-0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,-0.035224,
	0.180414,0.983591,0,0.210084,0.094169,-0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.356403,0.038624,-0.035224,
	0.180414,0.983591,0,0.210084,0.094169,-0.035224,
	0.526579,0.850126,0,0.356403,0.038624,-0.035224,
	0.526579,0.850126,0,0.210084,0.094169,0.035224,
	0.526579,0.850126,0,0.356403,0.038624,0.035224,
	-0.180414,0.983591,0,-0.356403,0.038624,0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,-0.035224,
	-0.354908,0.934901,0,-0.356403,0.038624,-0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,-0.035224,
	-0.180414,0.983591,0,-0.356403,0.038624,0.035224,
	-0.180414,0.983591,0,-0.210084,0.094169,0.035224
};
static const struct gllist frame={GL_N3F_V3F,GL_TRIANGLES,54,data,NULL};
const struct gllist *toaster_handle=&frame;
